
#line 3 "scan_settings.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 131
#define YY_END_OF_BUFFER 132
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[989] =
    {   0,
        0,    0,    0,    0,  132,  130,  129,  129,    1,  130,
      127,  130,  130,  130,  130,  130,  130,  130,  130,  130,
      130,  130,  130,  130,  130,  130,  130,  130,  130,  130,
      130,  130,  130,  130,  130,  130,   12,    3,    2,  131,
        0,  126,  127,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   54,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,   12,   11,    4,    5,    9,   10,
        6,    8,    7,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   56,    0,    0,
        0,    0,    0,   80,    0,    0,    0,   53,    4,    5,
       65,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  102,   25,    0,    0,    0,    0,    0,   77,    0,
        0,   50,    0,   96,    0,    0,    0,    0,   79,    0,
        0,    0,   83,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   31,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   39,   44,   33,    0,
       82,    0,    0,    0,    0,    0,    0,    4,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   98,    0,   99,    0,    0,    0,    0,
        0,    0,    0,   48,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,   32,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   52,    0,    0,
        0,    0,   72,   46,    0,    0,    0,   18,    0,    0,
        0,   34,    0,    0,    0,    0,   16,    0,    0,    0,
        0,    0,    0,   51,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   86,   35,    0,    0,    0,
        0,    0,    0,    0,   42,    0,    0,    0,    0,   95,
       47,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       20,   76,    0,    0,    0,    0,    0,    0,    0,    0,
      103,    0,    0,    0,    0,    0,    0,    0,    0,    0,

       38,   64,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   36,  101,   37,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   69,    0,    0,    0,    0,   68,
        0,    0,    0,    0,    0,   45,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   30,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   73,    0,    0,

       75,    0,   74,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   67,    0,    0,   17,    0,    0,    0,
       66,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   97,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   91,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   78,    0,    0,   43,    0,    0,
        0,    0,    0,    0,    0,  128,    0,   24,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       40,    0,    0,   61,   92,    0,    0,    0,    0,   14,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   94,    0,    0,   81,    0,    0,   70,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   13,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  119,    0,    0,    0,    0,   41,    0,    0,

        0,   93,    0,    0,    0,    0,    0,    0,    0,  104,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   90,  118,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       57,    0,    0,  116,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   15,    0,    0,
        0,   26,  105,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  100,    0,    0,    0,    0,   87,   62,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   71,    0,    0,   27,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   88,    0,  115,    0,    0,    0,    0,    0,
        0,    0,    0,   29,    0,    0,    0,    0,    0,    0,
      122,   89,   55,    0,    0,    0,    0,    0,    0,    0,
       84,    0,    0,   23,    0,    0,    0,    0,   60,    0,
        0,  114,    0,    0,    0,    0,    0,    0,   49,    0,
      123,    0,    0,    0,  106,    0,    0,    0,   19,    0,
        0,    0,    0,    0,    0,    0,    0,  120,    0,    0,

        0,    0,    0,    0,   21,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   85,    0,   63,    0,    0,   58,    0,
        0,    0,    0,    0,    0,    0,    0,  121,   22,  124,
      117,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  109,
        0,    0,    0,    0,    0,    0,    0,    0,  112,    0,
      108,    0,   28,    0,    0,    0,  110,  125,    0,    0,
        0,  107,    0,    0,  113,   59,  111,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    5,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    6,    1,    1,    7,    7,    7,
        7,    7,    7,    7,    7,    8,    8,    1,    1,    1,
        1,    1,    1,    1,    9,   10,    9,   11,    9,   12,
        1,    1,    1,    1,    1,   13,    1,   14,    1,    1,
        1,    1,    1,    1,   15,    1,    1,    1,    1,    1,
       16,   17,   18,    1,   19,    1,   20,   21,   22,   23,

       24,   25,   26,   27,   28,    1,   29,   30,   31,   32,
       33,   34,   35,   36,   37,   38,   39,   40,   41,   42,
       43,   44,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[45] =
    {   0,
        1,    2,    3,    3,    1,    1,    4,    4,    4,    4,
        4,    4,    1,    1,    1,    1,    3,    1,    1,    4,
        4,    4,    4,    4,    4,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[1001] =
    {   0,
        0,    0,   42,   44, 1027, 1028, 1028, 1028, 1028, 1023,
       43, 1010, 1022,   31,   33,   53,  999,   18,   29,  992,
      997,   32,   39,   51,   32,   54,  982,   33,  991,   70,
       69,   77,   44,   78,   69,  994,    0, 1028, 1028,  114,
     1014, 1028,  101, 1003, 1013,    0,  981,  975,  990,  973,
      976,  977,  984,  983,   79,  963,  969,   92,  968,  979,
      980,  971,  968,  966,  970,  967,  971,  952,  964,   87,
      968,  960,  103,   96,  952,  952,  947,   94,  961,   93,
      963,  954,  953,  110,  958,  950,  946,  106,  942,  956,
      959,  941,  102,  953,  106,  933,  941,  935,  949,  942,

      109,   48,  939,  933,    0, 1028,  141,  146, 1028, 1028,
     1028, 1028, 1028,  956,    0,  932,  934,  937,  927,  927,
      925,  940,  941,  929,  118,  927,  924,  920,  917,  935,
      921,  917,  922,  927,  912,  928,  922,  923,  913,  924,
      914,  917,  904,  903,  911,  910,  132,  910,  898,  899,
      907,  896,  909,  900,  907,  892,  905,   76,  902,  904,
      893,  892,  886,  896,  884,  897,  896,  882,  880,  893,
      886,  885,  880,  875,  881,  887,  867, 1028,  885,  871,
      871,  884,  867,  881,  867,  878,  873, 1028,  150,  154,
     1028,    0,  862,  869,  872,  864,  877,  871,  865,  857,

      872,  858,  866,  851,  850,  854,  860,  846,  848,  840,
      843, 1028, 1028,  861,  853,  860,  859,  849, 1028,  852,
      126, 1028,  837,  855,  134,  841,  833,  832, 1028,  846,
      829,  849, 1028,  843,  830,  846,  828,  837,  843,  818,
      827,  826,  832,  837,  818, 1028,  831,  832,  825,  829,
      817,  820,  816,  829,  828,  822, 1028, 1028, 1028,  821,
      812,  810,  815,  808,  814,  130,  801,  161,    0,  819,
      804,  800,  803,  803,  797,  813,  812,  798,  799,  796,
      804,  793,  789, 1028,  794, 1028,  790,  799,  791,  782,
      150,  788,  786, 1028,  134,  793,  783,  778,  794,  789,

      793,  773,  779,  790,  784,  769, 1028,  787,  779,  771,
      764,  764,  782,  769,  761,  770,  761, 1028,  764,  757,
      761,  760,  773,  767,  764,  764,  150,  751,  764,  766,
      754, 1028,  743,  746,  742,  744, 1028,    0,  749,  753,
      745,  758,  752, 1028,  739,  753,  750,  748,  733,  737,
      750,  749,  729,  734,  741, 1028, 1028,  742,  735,  738,
      738,  736,  722,  721, 1028,  733,  734,  715,  149, 1028,
     1028,  732,  734,  714,  713,  711,  724,  720,  709,  164,
     1028, 1028,  714,  707,  157,  720,  711,  701,  157,  705,
     1028,  712,  706,  705,  701,  161,  717,  716,  703,  709,

      713, 1028,  707,  702,    0,  705,  700,  688,  693,  688,
      685,  703, 1028, 1028, 1028,  681,  697,  698,  700,  694,
      698,  678,  684,  677,  685,  675,  687,  673,  672,  680,
      683,  686,  681,  665,  667,  659,  677,  672,  674,  679,
      654,  668,  671,  656, 1028,  674,  658,  671,  667, 1028,
      657,  657,  654,  666,  657, 1028,  654,  653,  659,  653,
      643,  635,  655,  639,  652,  656,  641,  637,  639,    0,
      634,  638,  637,  634,  630,  634,  643,  632,  627,  629,
      155, 1028,  625,  632,  635,  621,  625,  619,  619,  626,
      616,  622,  621,  622,  612,  612,  623, 1028,  604,  626,

     1028,  607, 1028,  607,  605,  598,  159,  607,  599,  619,
      618,  613,  599,  597,  602,  608,  598,  606,  605,  591,
      603,  598,  587, 1028,  593,  589,  603,  589,  190,  583,
     1028,  596,  598,  597,  586,  586,  595,  577,  582,  572,
      586,  570,  575,  574,  586,  579,  576,  584,  569,  573,
      572, 1028,  569,  561,  560,  559,  557,  557,  571,  568,
      567, 1028,  566,  561,  547,  563,  545,  173,  566,  563,
      546,  558,  544,  544, 1028,  547,  550, 1028,  541,  533,
      551,  554,  163,  536,  197, 1028,  552, 1028,  549,  544,
      545,  542,  529,  533,  532,  528,  521,  530,  529,  521,

      533,  521,  524,  522,  523,  521,  515,  528,  531,  517,
      516,  529,  525,  510,  523,  506,  506,  511,  517,  504,
      511,  505,  513,  183,  508,  504,  506,  492,  499,  512,
     1028,  492,  496, 1028, 1028,   45,   92,  117,  140, 1028,
      158,  158,  181,  166,  173,  182,  176,  177,  177,  179,
      188, 1028,  181,  196, 1028,  189,  189, 1028,  191,  196,
      202,  200,  191,  198,  207,  194,  203,  194,  214,  197,
      211,  200,  218,  206,  203,  203,  204,  212,  212,  220,
      222,  213,  208,  225,  229,  218,  214,  224,  228,  211,
      232,  219, 1028,  234,  226,  229,  242, 1028,  229,  244,

      240, 1028,  246,  247,  237,  231,  245,  251,  247, 1028,
      233,  240,  246,  241,  264,  255,  258,  246,  243,  243,
      263,  260,  263,  248,  249,  259,  264,  252,  267,  255,
      254,  265,  256,  258,  276,  259,  261, 1028, 1028,  256,
      270,  262,  278,  272,  268,  283,  266,  269,  274,  281,
     1028,  273,  280, 1028,  274,  283,  280,  277,  306,  284,
      292,  280,  300,  293,  299,  290,  296,  305,  285,  305,
      295,  292,  306,  308,  313,  297,  306, 1028,  309,  293,
      313, 1028, 1028,  306,  306,  316,  322,  309,  319,  316,
      312,  324, 1028,  323,  320,  316,  312, 1028, 1028,  319,

      328,  315,  314,  324,  328,  316,  335,  333,  327,  318,
      323,  343,  332,  346,  335, 1028,  334,  344, 1028,  331,
      347,  332,  335,  351,  344,  345,  345,  347,  335,  342,
      347,  345, 1028,  345, 1028,  364,  356,  361,  350,  368,
      365,  365,  354, 1028,  353,  366,  374,  363,  371,  364,
      378, 1028, 1028,  360,  362,  367,  368,  365,  379,  376,
     1028,  368,  374, 1028,  374,  377,  377,  377, 1028,  378,
      388, 1028,  390,  395,  391,  385,  393,  381, 1028,  381,
     1028,  400,  391,  386, 1028,  390,  402,  405, 1028,  396,
      403,  402,  390,  396,  399,  413,  402, 1028,  410,  398,

      399,  409,  412,  406, 1028,  401,  398,  416,  419,  407,
      426,  408,  427,  429,  418,  426,  414,  415,  433,  423,
      431,  420,  419, 1028,  434, 1028,  422,  422, 1028,  439,
      431,  439,  427,  428,  446,  441,  444, 1028, 1028, 1028,
     1028,  449,  442,  443,  448,  436,  437,  455,  450,  453,
      445,  453,  449,  443,  445,  446,  464,  459,  462, 1028,
      448,  464,  465,  447,  454,  472,  467,  470, 1028,  457,
     1028,  463, 1028,  477,  472,  475, 1028, 1028,  461,  475,
      478, 1028,  465,  480, 1028, 1028, 1028, 1028,  504,  508,
      511,  515,  519,  510,  514,  520,  521,  522,  523,  524

    } ;

static yyconst flex_int16_t yy_def[1001] =
    {   0,
      988,    1,  989,  989,  988,  988,  988,  988,  988,  990,
      988,  988,  991,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  992,  988,  988,  993,
      990,  988,  988,  988,  991,  994,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,

      988,  988,  988,  988,  992,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  995,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  996,  988,  988,  988,  988,  988,  988,  988,  988,

      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  997,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,

      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  998,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,

      988,  988,  988,  988,  999,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988, 1000,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,

      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,

      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,

      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,

      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,

      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,    0,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988

    } ;

static yyconst flex_int16_t yy_nxt[1073] =
    {   0,
        6,    7,    8,    9,   10,   11,   11,   11,    6,    6,
        6,    6,    6,   12,    6,   13,    6,    6,    6,   14,
       15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
       25,   26,   27,   28,   29,   30,   31,   32,   33,    6,
       34,   35,   36,    6,   38,   39,   38,   39,   43,   43,
       43,   47,   49,   59,   66,   74,   62,   60,   40,   61,
       40,   63,   68,   67,   75,   80,   69,  185,   81,   48,
       70,   50,   51,   76,   71,   98,   52,   77,   72,   53,
       99,  687,   54,   73,  186,   55,   78,  102,   56,   83,
       87,   57,   88,   84,  238,   89,  103,   85,   90,   91,

       93,  100,   86,   94,   95,  101,   43,   43,   43,  124,
      125,   92,  129,  688,   96,  239,  130,  126,  148,   97,
      107,  108,  142,  143,  146,  153,  154,  149,  147,  156,
      161,  183,  173,  157,  109,  167,  176,  177,  110,  162,
      184,  689,  168,  174,  295,  111,  163,  189,  190,  112,
      225,  113,  190,  190,  202,  203,  268,  190,  299,  226,
      190,  190,  296,  300,  227,  335,  336,  190,  190,  358,
      362,  393,  363,  432,  442,  447,  540,  690,  452,  433,
      394,  453,  395,  691,  461,  692,  396,  359,  462,  563,
      454,  585,  541,  448,  455,  638,  564,  622,  585,  443,

      639,  444,  677,  623,  693,  694,  624,  586,  695,  696,
      625,  697,  698,  699,  586,  678,  700,  701,  702,  703,
      704,  705,  706,  707,  708,  709,  710,  711,  712,  713,
      714,  715,  716,  717,  718,  719,  720,  722,  723,  724,
      725,  726,  727,  728,  729,  730,  731,  732,  733,  734,
      735,  736,  737,  738,  721,  739,  740,  741,  742,  743,
      744,  745,  746,  747,  748,  749,  750,  751,  752,  753,
      754,  755,  756,  757,  758,  759,  760,  761,  762,  763,
      764,  765,  766,  767,  768,  769,  770,  771,  772,  773,
      774,  775,  776,  777,  778,  779,  780,  781,  782,  783,

      784,  785,  786,  787,  788,  789,  790,  791,  792,  793,
      794,  795,  796,  797,  798,  799,  800,  801,  802,  803,
      804,  805,  806,  807,  808,  809,  810,  811,  812,  813,
      814,  815,  816,  817,  818,  819,  820,  821,  822,  823,
      824,  825,  826,  827,  828,  829,  830,  831,  832,  833,
      834,  835,  836,  837,  838,  839,  840,  841,  842,  843,
      844,  845,  846,  847,  848,  849,  850,  851,  852,  853,
      854,  855,  856,  857,  858,  859,  860,  861,  862,  863,
      864,  865,  866,  867,  868,  869,  870,  871,  872,  873,
      874,  875,  876,  877,  878,  879,  880,  881,  882,  883,

      884,  885,  886,  887,  888,  889,  890,  891,  892,  893,
      894,  895,  896,  897,  898,  899,  900,  901,  902,  903,
      904,  905,  906,  907,  908,  909,  910,  911,  912,  913,
      914,  915,  916,  917,  918,  919,  920,  921,  922,  923,
      924,  925,  926,  927,  928,  929,  930,  931,  932,  933,
      934,  935,  936,  937,  938,  939,  940,  941,  942,  943,
      944,  945,  946,  947,  948,  949,  950,  951,  952,  953,
      954,  955,  956,  957,  958,  959,  960,  961,  962,  963,
      964,  965,  966,  967,  968,  969,  970,  971,  972,  973,
      974,  975,  976,  977,  978,  979,  980,  981,  982,  983,

      984,  985,  986,  987,   37,   37,   37,   37,   41,   41,
       41,   41,   46,  115,   46,  105,  105,  192,  105,  106,
      106,  106,  106,  269,  338,  405,  470,  529,  686,  685,
      684,  683,  682,  681,  680,  679,  676,  675,  674,  673,
      672,  671,  670,  669,  668,  667,  666,  665,  664,  663,
      662,  661,  660,  659,  658,  657,  656,  655,  654,  653,
      652,  651,  650,  649,  648,  647,  646,  645,  644,  643,
      642,  641,  640,  637,  636,  635,  634,  633,  632,  631,
      630,  629,  628,  627,  626,  621,  620,  619,  618,  617,
      616,  615,  614,  613,  612,  611,  610,  609,  608,  607,

      606,  605,  604,  603,  602,  601,  600,  599,  598,  597,
      596,  595,  594,  593,  592,  591,  590,  589,  588,  587,
      584,  583,  582,  581,  580,  579,  578,  577,  576,  575,
      574,  573,  572,  571,  570,  569,  568,  567,  566,  565,
      562,  561,  560,  559,  558,  557,  556,  555,  554,  553,
      552,  551,  550,  549,  548,  547,  546,  545,  544,  543,
      542,  539,  538,  537,  536,  535,  534,  533,  532,  531,
      530,  528,  527,  526,  525,  524,  523,  522,  521,  520,
      519,  518,  517,  516,  515,  514,  513,  512,  511,  510,
      509,  508,  507,  506,  505,  504,  503,  502,  501,  500,

      499,  498,  497,  496,  495,  494,  493,  492,  491,  490,
      489,  488,  487,  486,  485,  484,  483,  482,  481,  480,
      479,  478,  477,  476,  475,  474,  473,  472,  471,  469,
      468,  467,  466,  465,  464,  463,  460,  459,  458,  457,
      456,  451,  450,  449,  446,  445,  441,  440,  439,  438,
      437,  436,  435,  434,  431,  430,  429,  428,  427,  426,
      425,  424,  423,  422,  421,  420,  419,  418,  417,  416,
      415,  414,  413,  412,  411,  410,  409,  408,  407,  406,
      404,  403,  402,  401,  400,  399,  398,  397,  392,  391,
      390,  389,  388,  387,  386,  385,  384,  383,  382,  381,

      380,  379,  378,  377,  376,  375,  374,  373,  372,  371,
      370,  369,  368,  367,  366,  365,  364,  361,  360,  357,
      356,  355,  354,  353,  352,  351,  350,  349,  348,  347,
      346,  345,  344,  343,  342,  341,  340,  339,  337,  334,
      333,  332,  331,  330,  329,  328,  327,  326,  325,  324,
      323,  322,  321,  320,  319,  318,  317,  316,  315,  314,
      313,  312,  311,  310,  309,  308,  307,  306,  305,  304,
      303,  302,  301,  298,  297,  294,  293,  292,  291,  290,
      289,  288,  287,  286,  285,  284,  283,  282,  281,  280,
      279,  278,  277,  276,  275,  274,  273,  272,  271,  270,

      267,  266,  265,  264,  263,  262,  261,  260,  259,  258,
      257,  256,  255,  254,  253,  252,  251,  250,  249,  248,
      247,  246,  245,  244,  243,  242,  241,  240,  237,  236,
      235,  234,  233,  232,  231,  230,  229,  228,  224,  223,
      222,  221,  220,  219,  218,  217,  216,  215,  214,  213,
      212,  211,  210,  209,  208,  207,  206,  205,  204,  201,
      200,  199,  198,  197,  196,  195,  194,  193,  191,  188,
      187,  182,  181,  180,  179,  178,  175,  172,  171,  170,
      169,  166,  165,  164,  160,  159,  158,  155,  152,  151,
      150,  145,  144,  141,  140,  139,  138,  137,  136,  135,

      134,  133,  132,  131,  128,  127,  123,  122,  121,  120,
      119,  118,  117,  116,   45,  114,   42,  104,   82,   79,
       65,   64,   58,   45,   44,   42,  988,    5,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988
    } ;

static yyconst flex_int16_t yy_chk[1073] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    3,    3,    4,    4,   11,   11,
       11,   14,   15,   18,   22,   25,   19,   18,    3,   18,
        4,   19,   23,   22,   25,   28,   23,  102,   28,   14,
       24,   15,   16,   26,   24,   33,   16,   26,   24,   16,
       33,  636,   16,   24,  102,   16,   26,   35,   16,   30,
       31,   16,   31,   30,  158,   31,   35,   30,   31,   31,

       32,   34,   30,   32,   32,   34,   43,   43,   43,   55,
       55,   31,   58,  637,   32,  158,   58,   55,   74,   32,
       40,   40,   70,   70,   73,   78,   78,   74,   73,   80,
       84,  101,   93,   80,   40,   88,   95,   95,   40,   84,
      101,  638,   88,   93,  221,   40,   84,  107,  107,   40,
      147,   40,  108,  108,  125,  125,  189,  189,  225,  147,
      190,  190,  221,  225,  147,  266,  266,  268,  268,  291,
      295,  327,  295,  369,  380,  385,  481,  639,  389,  369,
      327,  389,  327,  641,  396,  642,  327,  291,  396,  507,
      389,  529,  481,  385,  389,  583,  507,  568,  585,  380,

      583,  380,  624,  568,  643,  644,  568,  529,  645,  646,
      568,  647,  648,  649,  585,  624,  650,  651,  653,  654,
      656,  657,  659,  660,  661,  662,  663,  664,  665,  666,
      667,  668,  669,  670,  671,  672,  673,  674,  675,  676,
      677,  678,  679,  680,  681,  682,  683,  684,  685,  686,
      687,  688,  689,  690,  673,  691,  692,  694,  695,  696,
      697,  699,  700,  701,  703,  704,  705,  706,  707,  708,
      709,  711,  712,  713,  714,  715,  716,  717,  718,  719,
      720,  721,  722,  723,  724,  725,  726,  727,  728,  729,
      730,  731,  732,  733,  734,  735,  736,  737,  740,  741,

      742,  743,  744,  745,  746,  747,  748,  749,  750,  752,
      753,  755,  756,  757,  758,  759,  760,  761,  762,  763,
      764,  765,  766,  767,  768,  769,  770,  771,  772,  773,
      774,  775,  776,  777,  779,  780,  781,  784,  785,  786,
      787,  788,  789,  790,  791,  792,  794,  795,  796,  797,
      800,  801,  802,  803,  804,  805,  806,  807,  808,  809,
      810,  811,  812,  813,  814,  815,  817,  818,  820,  821,
      822,  823,  824,  825,  826,  827,  828,  829,  830,  831,
      832,  834,  836,  837,  838,  839,  840,  841,  842,  843,
      845,  846,  847,  848,  849,  850,  851,  854,  855,  856,

      857,  858,  859,  860,  862,  863,  865,  866,  867,  868,
      870,  871,  873,  874,  875,  876,  877,  878,  880,  882,
      883,  884,  886,  887,  888,  890,  891,  892,  893,  894,
      895,  896,  897,  899,  900,  901,  902,  903,  904,  906,
      907,  908,  909,  910,  911,  912,  913,  914,  915,  916,
      917,  918,  919,  920,  921,  922,  923,  925,  927,  928,
      930,  931,  932,  933,  934,  935,  936,  937,  942,  943,
      944,  945,  946,  947,  948,  949,  950,  951,  952,  953,
      954,  955,  956,  957,  958,  959,  961,  962,  963,  964,
      965,  966,  967,  968,  970,  972,  974,  975,  976,  979,

      980,  981,  983,  984,  989,  989,  989,  989,  990,  990,
      990,  990,  991,  994,  991,  992,  992,  995,  992,  993,
      993,  993,  993,  996,  997,  998,  999, 1000,  633,  632,
      630,  629,  628,  627,  626,  625,  623,  622,  621,  620,
      619,  618,  617,  616,  615,  614,  613,  612,  611,  610,
      609,  608,  607,  606,  605,  604,  603,  602,  601,  600,
      599,  598,  597,  596,  595,  594,  593,  592,  591,  590,
      589,  587,  584,  582,  581,  580,  579,  577,  576,  574,
      573,  572,  571,  570,  569,  567,  566,  565,  564,  563,
      561,  560,  559,  558,  557,  556,  555,  554,  553,  551,

      550,  549,  548,  547,  546,  545,  544,  543,  542,  541,
      540,  539,  538,  537,  536,  535,  534,  533,  532,  530,
      528,  527,  526,  525,  523,  522,  521,  520,  519,  518,
      517,  516,  515,  514,  513,  512,  511,  510,  509,  508,
      506,  505,  504,  502,  500,  499,  497,  496,  495,  494,
      493,  492,  491,  490,  489,  488,  487,  486,  485,  484,
      483,  480,  479,  478,  477,  476,  475,  474,  473,  472,
      471,  469,  468,  467,  466,  465,  464,  463,  462,  461,
      460,  459,  458,  457,  455,  454,  453,  452,  451,  449,
      448,  447,  446,  444,  443,  442,  441,  440,  439,  438,

      437,  436,  435,  434,  433,  432,  431,  430,  429,  428,
      427,  426,  425,  424,  423,  422,  421,  420,  419,  418,
      417,  416,  412,  411,  410,  409,  408,  407,  406,  404,
      403,  401,  400,  399,  398,  397,  395,  394,  393,  392,
      390,  388,  387,  386,  384,  383,  379,  378,  377,  376,
      375,  374,  373,  372,  368,  367,  366,  364,  363,  362,
      361,  360,  359,  358,  355,  354,  353,  352,  351,  350,
      349,  348,  347,  346,  345,  343,  342,  341,  340,  339,
      336,  335,  334,  333,  331,  330,  329,  328,  326,  325,
      324,  323,  322,  321,  320,  319,  317,  316,  315,  314,

      313,  312,  311,  310,  309,  308,  306,  305,  304,  303,
      302,  301,  300,  299,  298,  297,  296,  293,  292,  290,
      289,  288,  287,  285,  283,  282,  281,  280,  279,  278,
      277,  276,  275,  274,  273,  272,  271,  270,  267,  265,
      264,  263,  262,  261,  260,  256,  255,  254,  253,  252,
      251,  250,  249,  248,  247,  245,  244,  243,  242,  241,
      240,  239,  238,  237,  236,  235,  234,  232,  231,  230,
      228,  227,  226,  224,  223,  220,  218,  217,  216,  215,
      214,  211,  210,  209,  208,  207,  206,  205,  204,  203,
      202,  201,  200,  199,  198,  197,  196,  195,  194,  193,

      187,  186,  185,  184,  183,  182,  181,  180,  179,  177,
      176,  175,  174,  173,  172,  171,  170,  169,  168,  167,
      166,  165,  164,  163,  162,  161,  160,  159,  157,  156,
      155,  154,  153,  152,  151,  150,  149,  148,  146,  145,
      144,  143,  142,  141,  140,  139,  138,  137,  136,  135,
      134,  133,  132,  131,  130,  129,  128,  127,  126,  124,
      123,  122,  121,  120,  119,  118,  117,  116,  114,  104,
      103,  100,   99,   98,   97,   96,   94,   92,   91,   90,
       89,   87,   86,   85,   83,   82,   81,   79,   77,   76,
       75,   72,   71,   69,   68,   67,   66,   65,   64,   63,

       62,   61,   60,   59,   57,   56,   54,   53,   52,   51,
       50,   49,   48,   47,   45,   44,   41,   36,   29,   27,
       21,   20,   17,   13,   12,   10,    5,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988,  988,  988,  988,  988,  988,  988,  988,  988,
      988,  988
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "scan_settings.l"
/* -*-c-*- */
#line 3 "scan_settings.l"
/**-*-c-*-****************************************************************/
/* scan_settings.l - config file scanner for qingy                       */
/*                                                                       */
/*  Copyright (C) 2003      Paolo Gianrossi                              */
/*            (C) 2004-2006 Michele Noberasco                            */
/*  All rights reserved                                                  */
/*  by Paolo Gianrossi   <paolino.gnu@disi.unige.it>                     */
/*     Michele Noberasco <s4t4n@gentoo.org>                              */
/*                                                                       */
/* This program is free software; you can redistribute it and/or         */
/* modify  under the terms of the GNU General Public License as          */
/* published by the Free Software Foundation; either version 2, or (at   */
/* your option) any later version.                                       */
/*                                                                       */
/* This program is distributed in the hope that it will be useful, but   */
/* WITHOUT ANY WARRANTY; without even the implied warranty of            */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     */
/* General Public License for more details.                              */
/*                                                                       */
/* You should have received a copy of the GNU General Public License     */
/* along with GNU Emacs; see the file COPYING.  If not, write to the     */
/* Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.     */
/*************************************************************************/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <string.h>
#include <time.h>
#include "parse_settings.h"

#include "load_settings.h"
#include "misc.h"
#include "logger.h"

#define MAX_STR_CONST 256

char string_buf[MAX_STR_CONST];
char *string_buf_ptr;
YY_BUFFER_STATE settings_buf=NULL;
FILE *theme_fp=NULL;

extern int in_theme;
extern int yyparse();


#line 1061 "scan_settings.c"

#define INITIAL 0
#define stringa 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

int yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 53 "scan_settings.l"


	/* quted string defn */

#line 1249 "scan_settings.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 989 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1028 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 57 "scan_settings.l"
string_buf_ptr = string_buf; BEGIN(stringa);
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 59 "scan_settings.l"
{ 
  /* saw closing quote - all done */
  BEGIN(INITIAL);
  *string_buf_ptr = '\0';
  yylval.str=strdup(string_buf);
  return QUOTSTR_T;
}
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 67 "scan_settings.l"
{
  /* error - unterminated string constant */
  /* generate error message */
}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 72 "scan_settings.l"
{
  /* octal escape sequence */
  unsigned int result;
  
  (void) sscanf( yytext + 1, "%o", &result );
  
  if ( result > 0xff )
    /* error, constant is out-of-bounds */
    
    *string_buf_ptr++ = result;
}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 84 "scan_settings.l"
{
  /* generate error - bad escape sequence; something
   * like '\48' or '\0777777'
   */
}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 90 "scan_settings.l"
*string_buf_ptr++ = '\n';
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 91 "scan_settings.l"
*string_buf_ptr++ = '\t';
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 92 "scan_settings.l"
*string_buf_ptr++ = '\r';
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 93 "scan_settings.l"
*string_buf_ptr++ = '\b';
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 94 "scan_settings.l"
*string_buf_ptr++ = '\f';
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 96 "scan_settings.l"
*string_buf_ptr++ = yytext[1];
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 98 "scan_settings.l"
{
  char *yptr = yytext;
  
  while ( *yptr )
    *string_buf_ptr++ = *yptr++;
}
	YY_BREAK
/* end of quoted string defn */
/* keywords */
case 13:
YY_RULE_SETUP
#line 107 "scan_settings.l"
return SCREENSAVER_TOK;
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 108 "scan_settings.l"
return XSESSION_DIR_TOK;
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 109 "scan_settings.l"
return TXTSESSION_DIR_TOK;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 110 "scan_settings.l"
return XINIT_TOK;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 111 "scan_settings.l"
return X_SERVER_TOK;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 112 "scan_settings.l"
return THEME_TOK;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 113 "scan_settings.l"
return THEME_RES_TOK;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 114 "scan_settings.l"
return RAND_TOK;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 115 "scan_settings.l"
return DEFAULT_TXT_COL_TOK;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 116 "scan_settings.l"
return DEFAULT_CUR_COL_TOK;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 117 "scan_settings.l"
return OTHER_TXT_COL_TOK;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 118 "scan_settings.l"
return BG_TOK;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 119 "scan_settings.l"
return FONT_TOK;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 120 "scan_settings.l"
return BUTTON_OPAC_TOK;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 121 "scan_settings.l"
return WIN_OP_TOK;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 122 "scan_settings.l"
return SEL_WIN_OP_TOK;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 123 "scan_settings.l"
return SHUTDOWN_TOK;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 124 "scan_settings.l"
return EVERYONE_TOK;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 125 "scan_settings.l"
return ONLY_ROOT_TOK;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 126 "scan_settings.l"
return NO_ONE_TOK;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 127 "scan_settings.l"
return WTYPE_TOK;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 128 "scan_settings.l"
return WWIDTH_TOK;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 129 "scan_settings.l"
return WHEIGHT_TOK;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 130 "scan_settings.l"
return WCOMMAND_TOK;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 131 "scan_settings.l"
return WCONTENT_TOK;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 132 "scan_settings.l"
return WINDOW_TOK;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 133 "scan_settings.l"
return WPOLL_TIME_TOK;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 134 "scan_settings.l"
return WTEXT_COLOR_TOK;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 135 "scan_settings.l"
return WCURSOR_COLOR_TOK;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 136 "scan_settings.l"
return WINDOW_LINK_TOK;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 137 "scan_settings.l"
return WTEXT_SIZE_TOK;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 138 "scan_settings.l"
return WTEXT_TINY_TOK;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 139 "scan_settings.l"
return WTEXT_SMALLER_TOK;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 140 "scan_settings.l"
return WTEXT_SMALL_TOK;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 141 "scan_settings.l"
return WTEXT_MEDIUM_TOK;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 142 "scan_settings.l"
return WTEXT_LARGE_TOK;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 143 "scan_settings.l"
return WTEXT_ORIENTATION;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 144 "scan_settings.l"
return WTEXT_LEFT_TOK;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 145 "scan_settings.l"
return WTEXT_CENTER_TOK;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 146 "scan_settings.l"
return WTEXT_RIGHT_TOK;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 147 "scan_settings.l"
return YES_TOK;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 148 "scan_settings.l"
return NO_TOK;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 149 "scan_settings.l"
return CLEAR_BACKGROUND_TOK;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 150 "scan_settings.l"
return TTY_TOK;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 151 "scan_settings.l"
return LOCK_SESSIONS_TOK;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 152 "scan_settings.l"
return SCRSVR_TIMEOUT_TOK;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 153 "scan_settings.l"
return SCRN_POWER_TOK;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 154 "scan_settings.l"
return SCRSVRS_DIR_TOK;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 155 "scan_settings.l"
return THEMES_DIR_TOK;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 156 "scan_settings.l"
return DFB_INTERFACE_TOK;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 157 "scan_settings.l"
return RESET_CONSOLE_TOK;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 158 "scan_settings.l"
return X_ARGS_TOK;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 159 "scan_settings.l"
return NULL_TOK;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 160 "scan_settings.l"
return AUTOLOGIN_TOK;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 161 "scan_settings.l"
return USERNAME_TOK;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 162 "scan_settings.l"
return SESSION_TOK;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 163 "scan_settings.l"
return RELOGIN_TOK;
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 164 "scan_settings.l"
return LAST_SESSION_TOK;
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 165 "scan_settings.l"
return TEMP_FILES_DIR_TOK;
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 166 "scan_settings.l"
return SLEEP_TOK;
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 167 "scan_settings.l"
return NEXT_TTY_TOK;
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 168 "scan_settings.l"
return PREV_TTY_TOK;
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 169 "scan_settings.l"
return POWEROFF_TOK;
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 170 "scan_settings.l"
return REBOOT_TOK;
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 171 "scan_settings.l"
return KILL_TOK;
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 172 "scan_settings.l"
return TEXT_MODE_TOK;
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 173 "scan_settings.l"
return MENU_KEY_TOK;
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 174 "scan_settings.l"
return WIN_KEY_TOK;
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 175 "scan_settings.l"
return KEYBINDINGS_TOK;
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 176 "scan_settings.l"
return USER_TOK;
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 177 "scan_settings.l"
return NONE_TOK;
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 178 "scan_settings.l"
return LAST_USER_POLICY_TOK;
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 179 "scan_settings.l"
return LAST_SESSION_POLICY_TOK;
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 180 "scan_settings.l"
return GLOBAL_TOK;
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 181 "scan_settings.l"
return PRE_GUI_TOK;
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 182 "scan_settings.l"
return POST_GUI_TOK;
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 183 "scan_settings.l"
return X_SERVER_OFFSET_TOK;
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 184 "scan_settings.l"
return X_SERVER_TTY_TOK;
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 185 "scan_settings.l"
return QINGY_TTY_TOK;
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 186 "scan_settings.l"
return UNUSED_TTY_TOK;
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 187 "scan_settings.l"
return IDLE_TIMEOUT_TOK;
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 188 "scan_settings.l"
return IDLE_ACTION_TOK;
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 189 "scan_settings.l"
return LOGOUT_TOK;
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 190 "scan_settings.l"
return LOCK_TOK;
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 191 "scan_settings.l"
return LOG_LEVEL_TOK;
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 192 "scan_settings.l"
return DEBUG_TOK;
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 193 "scan_settings.l"
return ERROR_TOK;
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 194 "scan_settings.l"
return LOG_FACILITIES_TOK;
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 195 "scan_settings.l"
return CONSOLE_TOK;
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 196 "scan_settings.l"
return FILE_TOK;
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 197 "scan_settings.l"
return SYSLOG_TOK;
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 198 "scan_settings.l"
return MOUSE_CURSOR_TOK;
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 199 "scan_settings.l"
return CHECK_RUNLEVEL_TOK;
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 200 "scan_settings.l"
return EXCLUDE_RUNLEVELS_TOK;
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 201 "scan_settings.l"
return SHUTDOWN_TIMEOUT_MESSAGE_TOK;
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 202 "scan_settings.l"
return RESTART_TIMEOUT_MESSAGE_TOK;
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 203 "scan_settings.l"
return SLEEP_TIMEOUT_MESSAGE_TOK;
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 204 "scan_settings.l"
return SLEEP_FORBIDDEN_MESSAGE_TOK;
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 205 "scan_settings.l"
return SHUTDOWN_FORBIDDEN_MESSAGE_TOK;
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 206 "scan_settings.l"
return SLEEP_PASSWORD_MESSAGE_TOK;
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 207 "scan_settings.l"
return SHUTDOWN_PASSWORD_MESSAGE_TOK;
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 208 "scan_settings.l"
return SHUTDOWN_MESSAGE_TOK;
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 209 "scan_settings.l"
return RESTART_MESSAGE_TOK;
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 210 "scan_settings.l"
return LOGIN_MESSAGE_TOK;
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 211 "scan_settings.l"
return LOGIN_FAILED_MESSAGE_TOK;
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 212 "scan_settings.l"
return ABORT_MESSAGE_TOK;
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 213 "scan_settings.l"
return CAPS_MESSAGE_TOK;
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 214 "scan_settings.l"
return SLEEP_CMD_MESSAGE_TOK;
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 215 "scan_settings.l"
return CRYPTO_ERROR_MESSAGE_TOK;
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 216 "scan_settings.l"
return WELCOME_MESSAGE_TOK;
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 217 "scan_settings.l"
return COUNTDOWN_TIMEOUT_TOK;
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 218 "scan_settings.l"
return INFO_MESSAGE_TIMEOUT_TOK;
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 219 "scan_settings.l"
return WELCOME_MESSAGE_TIMEOUT_TOK;
	YY_BREAK
case 126:
/* rule 126 can match eol */
YY_RULE_SETUP
#line 222 "scan_settings.l"
;			/* skip comments */
	YY_BREAK
/* numbers */
case 127:
YY_RULE_SETUP
#line 225 "scan_settings.l"
{  sscanf(yytext, "%i", &(yylval.ival)); return ANUM_T;}	
	YY_BREAK
/* colors */
case 128:
YY_RULE_SETUP
#line 228 "scan_settings.l"
{ sscanf(yytext, "[%x]", (unsigned int *)yylval.color); return COLOR_T;}
	YY_BREAK
case 129:
/* rule 129 can match eol */
YY_RULE_SETUP
#line 230 "scan_settings.l"
; 			/* skip blanks */
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 232 "scan_settings.l"
return *yytext;
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 234 "scan_settings.l"
ECHO;
	YY_BREAK
#line 2023 "scan_settings.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(stringa):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 989 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 989 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 988);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef _UNISTD_H /* assume unistd.h has isatty() for us */
#ifdef __cplusplus
extern "C" {
#endif
#ifdef __THROW /* this is a gnuism */
extern int isatty (int ) __THROW;
#else
extern int isatty (int );
#endif
#ifdef __cplusplus
}
#endif
#endif
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 234 "scan_settings.l"



 /* do nothing at EOF */
int yywrap()
{
  if(settings_buf)
	{
    yy_delete_buffer(YY_CURRENT_BUFFER );
    yy_switch_to_buffer(settings_buf);
    settings_buf=NULL;
    got_theme=1;
    in_theme=0;
		fclose(theme_fp);
    return 0;
  }
  return 1;
}


int set_theme(char *theme)
{
	FILE *fp;
  char *file;

  if (!theme) return 0;
  
  theme_dir = StrApp((char**)NULL, themes_dir, "/", theme, "/", (char*)NULL);
  file = StrApp((char**)NULL, theme_dir, "theme", (char*)NULL);

  fp = fopen(file, "r");
	free(file);
  if (!fp)
	{
		WRITELOG(ERROR, "Theme '%s' does not exist in directory '%s'.\n", theme, theme_dir);
		return 0;
	}
	settings_buf=YY_CURRENT_BUFFER;
	theme_fp = yyin = fp;
  yy_switch_to_buffer(yy_create_buffer(yyin,YY_BUF_SIZE ) );
  in_theme = 1;
  return 1;
}


